@@ -137,6 +137,7 @@ COND_ARGS_NIL: int = ...
 NO_UNKNOWN_CONDS: int = ...
 STRICT_ARGS_COUNT: int = ...
 MEMPOOL_MODE: int = ...
+ELIGIBLE_FOR_DEDUP: int = ...
 
 NO_NEG_DIV: int = ...
 NO_UNKNOWN_OPS: int = ...
@@ -163,7 +164,7 @@ def get_puzzle_and_solution_for_coin(program: bytes, args: bytes, max_cost: int,
             "seconds_relative: int",
             "create_coin: List[Tuple[bytes, int, Optional[bytes]]]",
             "agg_sig_me: List[Tuple[bytes, bytes]]",
-            "eligible_for_dedup: bool",
+            "flags: int",
         ],
     )
 
