@@ -1,13 +1,14 @@
 use super::adapt_response::eval_err_to_pyresult;
-use super::from_json_dict::FromJsonDict;
-use super::to_json_dict::ToJsonDict;
+use chia_protocol::from_json_dict::FromJsonDict;
+use chia_protocol::to_json_dict::ToJsonDict;
 
-use chia::bytes::{Bytes, Bytes32, Bytes48};
+use chia_protocol::bytes::{Bytes, Bytes32, Bytes48};
 use chia::gen::conditions::{parse_spends, Spend, SpendBundleConditions};
 use chia::gen::validation_error::{ErrorCode, ValidationErr};
 
 use clvmr::allocator::Allocator;
 use clvmr::chia_dialect::ChiaDialect;
+use clvmr::chia_dialect::LIMIT_HEAP;
 use clvmr::cost::Cost;
 use clvmr::reduction::{EvalErr, Reduction};
 use clvmr::run_program::run_program;
@@ -15,44 +16,33 @@ use clvmr::serialize::node_from_bytes;
 
 use pyo3::prelude::*;
 
-use chia::chia_error;
-use chia::streamable::Streamable;
+use chia_protocol::chia_error;
+use chia_protocol::streamable::Streamable;
 use chia_streamable_macro::Streamable;
-use py_streamable::PyStreamable;
+use chia_py_streamable_macro::PyStreamable;
 
 #[pyclass(name = "Spend")]
 #[derive(Streamable, PyStreamable, Hash, Debug, Clone, Eq, PartialEq)]
 pub struct PySpend {
-    #[pyo3(get)]
     pub coin_id: Bytes32,
-    #[pyo3(get)]
     pub puzzle_hash: Bytes32,
-    #[pyo3(get)]
     pub height_relative: Option<u32>,
-    #[pyo3(get)]
     pub seconds_relative: u64,
-    #[pyo3(get)]
     pub create_coin: Vec<(Bytes32, u64, Option<Bytes>)>,
-    #[pyo3(get)]
     pub agg_sig_me: Vec<(Bytes48, Bytes)>,
+    pub flags: u32,
 }
 
 #[pyclass(name = "SpendBundleConditions")]
 #[derive(Streamable, PyStreamable, Hash, Debug, Clone, Eq, PartialEq)]
 pub struct PySpendBundleConditions {
-    #[pyo3(get)]
     pub spends: Vec<PySpend>,
-    #[pyo3(get)]
     pub reserve_fee: u64,
-    #[pyo3(get)]
     // the highest height/time conditions (i.e. most strict)
     pub height_absolute: u32,
-    #[pyo3(get)]
     pub seconds_absolute: u64,
     // Unsafe Agg Sig conditions (i.e. not tied to the spend generating it)
-    #[pyo3(get)]
     pub agg_sig_unsafe: Vec<(Bytes48, Bytes)>,
-    #[pyo3(get)]
     pub cost: u64,
 }
 
@@ -82,6 +72,7 @@ fn convert_spend(a: &Allocator, spend: Spend) -> PySpend {
         seconds_relative: spend.seconds_relative,
         create_coin,
         agg_sig_me: agg_sigs,
+        flags: spend.flags,
     }
 }
 
@@ -109,6 +100,7 @@ fn convert_spend_bundle_conds(a: &Allocator, sb: SpendBundleConditions) -> PySpe
 // returns the cost of running the CLVM program along with conditions and the list of
 // spends
 #[pyfunction]
+#[allow(clippy::borrow_deref_ref)]
 pub fn run_generator(
     py: Python,
     program: &[u8],
@@ -116,7 +108,11 @@ pub fn run_generator(
     max_cost: Cost,
     flags: u32,
 ) -> PyResult<(Option<u32>, Option<PySpendBundleConditions>)> {
-    let mut allocator = Allocator::new();
+    let mut allocator = if flags & LIMIT_HEAP != 0 {
+        Allocator::new_limited(500000000, 62500000, 62500000)
+    } else {
+        Allocator::new()
+    };
     let program = node_from_bytes(&mut allocator, program)?;
     let args = node_from_bytes(&mut allocator, args)?;
     let dialect = &ChiaDialect::new(flags);
